@@ -10,6 +10,7 @@ from rich.text import Text
 
 from .cached_object import CachedObject
 from .help_layout import HelpLayout
+from .config import box_type
 
 
 class OverviewState:
@@ -32,7 +33,7 @@ class Overview:
     def layout_width(self):
         return (self.term.width - 2) // 4 * 3
 
-    def get_layout(self, cached_obj: CachedObject):
+    def get_layout(self, cached_obj: CachedObject) -> Layout:
         """
         :param cached_obj: The selected cached object given by the explorer layout
         """
@@ -64,6 +65,8 @@ class Overview:
                 ),
             )
             return layout
+        else:
+            raise ValueError("Unexpected overview state")
 
     def get_value_panel(self, cached_obj: CachedObject):
         renderable: Union[str, Pretty, Syntax]
@@ -97,6 +100,7 @@ class Overview:
             subtitle=subtitle,
             subtitle_align="left",
             style=Style(color="white"),
+            box=box_type
         )
 
     def get_info_layout(self, cached_obj: CachedObject):
@@ -110,6 +114,7 @@ class Overview:
                         title="[i][cyan]len[/cyan]()[/i]",
                         title_align="left",
                         style="white",
+                        box=box_type
                     )
                 ),
             )
@@ -125,6 +130,7 @@ class Overview:
                 title="[i][cyan]type[/cyan]()[/i]",
                 title_align="left",
                 style="white",
+                box=box_type
             ),
             size=3,
         )
@@ -148,4 +154,5 @@ class Overview:
             subtitle=subtitle,
             subtitle_align="left",
             style="white",
+            box=box_type
         )
